aboutsummaryrefslogtreecommitdiffstats
path: root/core/events.go
diff options
context:
space:
mode:
Diffstat (limited to 'core/events.go')
-rw-r--r--core/events.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/events.go b/core/events.go
index 6f404f612..fee34b39d 100644
--- a/core/events.go
+++ b/core/events.go
@@ -21,8 +21,8 @@ import (
"github.com/ethereum/go-ethereum/core/types"
)
-// TxPreEvent is posted when a transaction enters the transaction pool.
-type TxPreEvent struct{ Tx *types.Transaction }
+// TxsPreEvent is posted when a batch of transactions enter the transaction pool.
+type TxsPreEvent struct{ Txs types.Transactions }
// PendingLogsEvent is posted pre mining and notifies of pending logs.
type PendingLogsEvent struct {